@@ -1,19 +1,19 @@
-#' Separate a character column into multiple columns using a regular
-#' expression separator
+#' Separate a character column into multiple columns with a regular
+#' expression or numeric locations
 #'
-#' Given either regular expression or a vector of character positions,
+#' Given either a regular expression or a vector of character positions,
 #' `separate()` turns a single character column into multiple columns.
 #'
 #' @inheritParams extract
 #' @param sep Separator between columns.
 #'
-#'   If character, is interpreted as a regular expression. The default
+#'   If character, `sep` is interpreted as a regular expression. The default
 #'   value is a regular expression that matches any sequence of
 #'   non-alphanumeric values.
 #'
-#'   If numeric, interpreted as positions to split at. Positive values start
-#'   at 1 at the far-left of the string; negative value start at -1 at the
-#'   far-right of the string. The length of `sep` should be one less than
+#'   If numeric, `sep` is interpreted as character positions to split at. Positive
+#'   values start at 1 at the far-left of the string; negative value start at -1 at
+#'   the far-right of the string. The length of `sep` should be one less than
 #'   `into`.
 #' @param extra If `sep` is a character vector, this controls what
 #'   happens when there are too many pieces. There are three valid options:
@@ -32,6 +32,7 @@
 #' @export
 #' @examples
 #' library(dplyr)
+#' # If you want to split by any non-alphanumeric value (the default):
 #' df <- data.frame(x = c(NA, "a.b", "a.d", "b.c"))
 #' df %>% separate(x, c("A", "B"))
 #'
@@ -39,32 +40,28 @@
 #' df %>% separate(x, c(NA, "B"))
 #'
 #' # If every row doesn't split into the same number of pieces, use
-#' # the extra and fill arguments to control what happens
+#' # the extra and fill arguments to control what happens:
 #' df <- data.frame(x = c("a", "a b", "a b c", NA))
 #' df %>% separate(x, c("a", "b"))
-#' # The same behaviour drops the c but no warnings
+#' # The same behaviour as previous, but drops the c without warnings:
 #' df %>% separate(x, c("a", "b"), extra = "drop", fill = "right")
-#' # Another option:
+#' # Opposite of previous, keeping the c and filling left:
 #' df %>% separate(x, c("a", "b"), extra = "merge", fill = "left")
-#' # Or you can keep all three
+#' # Or you can keep all three:
 #' df %>% separate(x, c("a", "b", "c"))
 #'
-#' # If only want to split specified number of times use extra = "merge"
+#' # To only split a specified number of times use extra = "merge":
 #' df <- data.frame(x = c("x: 123", "y: error: 7"))
 #' df %>% separate(x, c("key", "value"), ": ", extra = "merge")
 #'
 #' # Use regular expressions to separate on multiple characters:
 #' df <- data.frame(x = c(NA, "a?b", "a.d", "b:c"))
-#' df %>% separate(x, c("A","B"), sep = "([\\.\\?\\:])")
+#' df %>% separate(x, c("A","B"), sep = "([.?:])")
 #'
-#' # convert = TRUE detects column classes
+#' # convert = TRUE detects column classes:
 #' df <- data.frame(x = c("a:1", "a:2", "c:4", "d", NA))
 #' df %>% separate(x, c("key","value"), ":") %>% str
 #' df %>% separate(x, c("key","value"), ":", convert = TRUE) %>% str
-#'
-#' # Argument col can take quasiquotation to work with strings
-#' var <- "x"
-#' df %>% separate(!!var, c("key","value"), ":")
 separate <- function(data, col, into, sep = "[^[:alnum:]]+", remove = TRUE,
                      convert = FALSE, extra = "warn", fill = "warn", ...) {
   ellipsis::check_dots_used()
@@ -74,6 +71,7 @@ separate <- function(data, col, into, sep = "[^[:alnum:]]+", remove = TRUE,
 separate.data.frame <- function(data, col, into, sep = "[^[:alnum:]]+",
                                 remove = TRUE, convert = FALSE,
                                 extra = "warn", fill = "warn", ...) {
+  check_present(col)
   var <- tidyselect::vars_pull(names(data), !! enquo(col))
   value <- as.character(data[[var]])
 
