@@ -15,7 +15,7 @@ test_that("preserves grouping", {
   df <- tibble(x = 1:2, y = 1:2, z = 3:4) %>% dplyr::group_by(x)
   out <- complete(df, x, y)
   expect_s3_class(out, "grouped_df")
-  expect_equal(dplyr::groups(out), dplyr::groups(df))
+  expect_equal(dplyr::group_vars(out), dplyr::group_vars(df))
 })
 
 test_that("expands empty factors", {
@@ -28,10 +28,17 @@ test_that("expands empty factors", {
 
 test_that("empty expansion returns original", {
   df <- tibble(x = character())
-  rs <- complete(df, y = integer())
+  rs <- complete(df, y = NULL)
   expect_equal(rs, df)
 
   df <- tibble(x = 1:4)
-  rs <- complete(df, y = integer())
+  rs <- complete(df, y = NULL)
   expect_equal(rs, df)
 })
+
+test_that("not drop unspecified levels in complete", {
+  df <- tibble(x = 1:3, y = 1:3, z = c("a", "b", "c"))
+  df2 <- df %>% complete(z = c("a", "b"))
+  expect <- df[c("z", "x", "y")]
+  expect_equal(df2, expect)
+})
