@@ -13,10 +13,28 @@ test_that("multiple variables in one arg doesn't expand", {
 })
 
 test_that("nesting doesn't expand values", {
-  df <- data.frame(x = 1:2, y = 1:2)
+  df <- tibble(x = 1:2, y = 1:2)
   expect_equal(expand(df, nesting(x, y)), df)
 })
 
+test_that("unnamed data frames are flattened", {
+  df <- data.frame(x = 1:2, y = 1:2)
+  out <- expand(df, nesting(x, y))
+  expect_equal(out$x, df$x)
+
+  out <- crossing(df)
+  expect_equal(out$x, df$x)
+})
+
+test_that("named data frames are not flattened", {
+  df <- tibble(x = 1:2, y = 1:2)
+  out <- expand(df, x = nesting(x, y))
+  expect_equal(out$x, df)
+
+  out <- crossing(x = df)
+  expect_equal(out$x, df)
+})
+
 test_that("expand works with non-standard col names", {
   df <- tibble(` x ` = 1:2, `/y` = 1:2)
   out <- expand(df, ` x `, `/y`)
@@ -57,33 +75,33 @@ test_that("crossing preserves factor levels", {
   expect_equal(levels(crossing(x = x_na_lev_extra)$x), c("a", "b", NA))
 })
 
-test_that("zero length numeric & character inputs are automatically dropped", {
+test_that("NULL inputs", {
   tb <- tibble(x = 1:5)
-  expect_equal(expand(tb, x, y = numeric()), tb)
-  expect_equal(nesting(x = tb$x, y = numeric()), tb)
-  expect_equal(crossing(x = tb$x, y = numeric()), tb)
-
-  expect_equal(expand(tb, x, y = character()), tb)
-  expect_equal(nesting(x = tb$x, y = character()), tb)
-  expect_equal(crossing(x = tb$x, y = character()), tb)
+  expect_equal(expand(tb, x, y = NULL), tb)
+  expect_equal(nesting(x = tb$x, y = NULL), tb)
+  expect_equal(crossing(x = tb$x, y = NULL), tb)
 })
 
 test_that("zero length input gives zero length output", {
   tb <- tibble(x = character())
-  expect_equal(expand(tb, x), tibble())
+  expect_equal(expand(tb, x), tb)
   expect_equal(expand(tb, y = NULL), tibble())
+
+  expect_equal(
+    expand_grid(x = integer(), y = 1:3),
+    tibble(x = integer(), y = integer())
+  )
 })
 
-test_that("expand & crossing complete zero length factors, nesting doesn't", {
-  tb <- tibble(x = 1:2)
-  emptyfactor <- factor(levels = c("a", "b"))
-  targettb <- tibble(
-    x = as.integer(c(1, 1, 2, 2)),
-    y = factor(c("a", "b", "a", "b"), levels = c("a", "b"))
+test_that("expand & crossing expand missing factor leves; nesting does not", {
+  tb <- tibble(
+    x = 1:3,
+    f = factor("a", levels = c("a", "b"))
   )
-  expect_equal(expand(tb, x, y = emptyfactor), targettb)
-  expect_equal(nesting(x = tb$x, y = emptyfactor), tb)
-  expect_equal(crossing(x = tb$x, y = emptyfactor), targettb)
+
+  expect_equal(nrow(expand(tb, x, f)), 6)
+  expect_equal(nrow(crossing(!!!tb)), 6)
+  expect_equal(nrow(nesting(!!!tb)), nrow(tb))
 })
 
 test_that("expand() reconstructs input dots is empty", {
@@ -94,7 +112,7 @@ test_that("expand() reconstructs input dots is empty", {
 test_that("crossing checks for bad inputs", {
   expect_error(
     crossing(x = 1:10, y = quote(a)),
-    "Problems: y"
+    class = "vctrs_error_scalar_type"
   )
 })
 
@@ -108,3 +126,38 @@ test_that("crossing handles list columns", {
   expect_equal(out$x, rep(x, each = 2))
   expect_equal(out$y, rep(y, 2))
 })
+
+test_that("expand_grid can control name_repair", {
+  x <- 1:2
+
+  if (packageVersion("tibble") > "2.99") {
+    expect_error(expand_grid(x, x), class = "rlang_error")
+  } else {
+    expect_error(expand_grid(x, x), "must not be duplicated")
+  }
+
+  expect_message(out <- expand_grid(x, x, .name_repair = "unique"), "New names:")
+  expect_named(out, c("x...1", "x...2"))
+
+  out <- expand_grid(x, x, .name_repair = "minimal")
+  expect_named(out, c("x", "x"))
+})
+
+test_that("crossing/nesting/expand respect .name_repair", {
+
+  x <- 1:2
+  expect_named(crossing(x, x, .name_repair = "unique"), c("x...1", "x...2"))
+
+  expect_named(nesting(x, x, .name_repair = "unique"), c("x...1", "x...2"))
+
+  df <- tibble(x)
+  expect_named(df %>% expand(x, x, .name_repair = "unique"), c("x...1", "x...2"))
+})
+
+
+# dots_cols supports lazy evaluation --------------------------------------
+
+test_that("dots_cols evaluates each expression in turn", {
+  out <- dots_cols(x = seq(-2, 2), y = x)
+  expect_equal(out$x, out$y)
+})
